Chapter 7: Dimensionality and its Reduction
-------------------------------------------
This chapter covers dimensionality reduction, from linear methods such as
PCA, NMF, and ICA, to nonlinear methods such as LLE and Isomap.
